![MakeDjango](https://github.com/MahanBi/MakeDjango/blob/master/docs/images/MakeDjango.png)

[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/) ![GitHub](https://img.shields.io/github/license/MahanBi/MakeDjango) ![PyPI - Downloads](https://img.shields.io/pypi/dm/MakeDjango) ![PyPI](https://img.shields.io/pypi/v/MakeDjango) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/MakeDjango)

![GitHub watchers](https://img.shields.io/github/watchers/MahanBi/MakeDjango?style=social) ![GitHub Repo stars](https://img.shields.io/github/stars/MahanBi/MakeDjango?style=social) ![GitHub forks](https://img.shields.io/github/forks/MahanBi/MakeDjango?style=social)

# MakeDjango

- Document: Soon
- Pypi: [HERE](https://pypi.org/project/MakeDjango/)
- Version: 1.0.5

## What is MakeDjango?

A command line tool to speed up project construction ...

Its main purpose is to create the right template for each project mode.

(Create the folders and files needed for the project.)

### Installation

##### To install MakeDjango, use pip:

``` bash
pip install MakeDjango
```

Or to install from source:

``` bash
python setup.py install
```

### Usage

##### To display all commands:

``` bash
MakeDjango --help
```

##### To create a project automatically:

name: project name

mode: rest or django(jinja) or graphpl

appnames: exam-> app1 app2

``` bash
MakeDjango -a name mode apnames...
```

### License

MIT. See [LICENSE](https://github.com/MahanBi/MakeDjango/blob/master/LICENSE) for more details.
